@@ -2,7 +2,7 @@
 
 /*
     NUT nutrition software 
-    Copyright (C) 1996-2007 by Jim Jozwiak.
+    Copyright (C) 1996-2008 by Jim Jozwiak.
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -328,7 +328,7 @@ float one = 1;
 char buffer[100];
 header("NUT:  Add a Recipe");
 printf("%-60s   Grams:  %7.2f\n",food_work.name,food_work.grams);
-printf("Serving:  %-50s   Ounces: %7.2f\n",format_serving(buffer,&one,&food_work),food_work.grams / 28.35);
+printf("Serving:  %-50s   Ounces: %7.2f\n",format_serving(buffer,&one,&food_work),food_work.grams / GRAMS_IN_OUNCE);
 printf("          %-50s   Water:   %6.2f%%\n"," ",100 * food_work.nutrient[WATER] / food_work.grams);
 printf("Percentages of \"Daily Values\" in this serving:                 Refuse:  %3d%%\n\n",food_work.refuse);
 food_display(stdout);
@@ -340,7 +340,7 @@ void get_recipe_qty(float *result)
 char buff[128];
 fgets(buff,128,stdin);
 if (strchr(buff,'g') != NULL) *result = (float) atof(buff);
-else if (strchr(buff,'o') != NULL) *result = (float) atof(buff) * 28.35;
+else if (strchr(buff,'o') != NULL) *result = (float) atof(buff) * GRAMS_IN_OUNCE;
 else *result = atof(buff);
 }
 
@@ -357,7 +357,7 @@ while (recipe_ptr->next != NULL)
  if (! level)
   {
   if (options.grams) printf("%2d. %-60s    %9.1f g\n",count,recipe_ptr->name,recipe_ptr->grams);
-  if (!options.grams) printf("%2d. %-60s    %8.1f oz\n",count,recipe_ptr->name,recipe_ptr->grams/28.35);
+  if (!options.grams) printf("%2d. %-60s    %8.1f oz\n",count,recipe_ptr->name,recipe_ptr->grams/GRAMS_IN_OUNCE);
   }
  if (level)
   {
@@ -391,7 +391,7 @@ while (recipe_ptr->next != NULL)
   if (options.grams && ! trace) printf("    %9.1f g\n",recipe_ptr->grams);
   if (options.grams && trace && recipe_ptr->grams >  0) printf("    %9.2f g\n",recipe_ptr->grams);
   if (options.grams && trace && recipe_ptr->grams == 0) printf("      %9s\n","trace");
-  if (!options.grams) printf("    %8.1f oz\n",recipe_ptr->grams/28.35);
+  if (!options.grams) printf("    %8.1f oz\n",recipe_ptr->grams/GRAMS_IN_OUNCE);
   }
  }
 if (count == 0) 
@@ -562,6 +562,7 @@ int gt0dvnuts[DV_COUNT];
 int remaininggroupsassigner[DV_COUNT];
 int levelcumbuf[DV_COUNT] = {0,0,0,0,0,0,0,0,0,0,0,0};
 int levelminbuf[DV_COUNT] = {0,0,0,0,0,0,0,0,0,0,0,0};
+int levelmaxbuf[DV_COUNT] = {0,0,0,0,0,0,0,0,0,0,0,0};
 int parentheses[2 * DV_COUNT];
 float gt0dvnutfactors[DV_COUNT];
 char *token;
@@ -655,12 +656,13 @@ for (i = GRfoodcount - 1; i > 0; i--)
   }
  }
 
-GRbestvariance = GRtotalquanta * GRtotalquanta * (GRnutcount + 2);
+GRbestvariance = 1e38;
 
 for (i = 0; i < GRfoodcount; i++) GRfoodslots[i] = 0;
 if (GRfoodcount > 10) GRtotalquanta = 40;
 levelcumbuf[0] = levelminbuf[0] = GRtotalquanta;
-solve_it(0,levelcumbuf,levelminbuf);
+
+solve_it(0,levelcumbuf,levelminbuf,levelmaxbuf);
 
 for (i = 0; i < GRfoodcount; i++) foodlist[i]->grams = GRsaveslots[i] * food_work.grams / GRtotalquanta;
 
@@ -688,20 +690,34 @@ token = NULL;
 while (recipe_root.next != NULL) modify_recipe_food(1,token);
 }
 
-void solve_it(int foodno, int *oldlevelcumbuf, int *oldlevelminbuf)
+void solve_it(int foodno, int *oldlevelcumbuf, int *oldlevelminbuf, int *oldlevelmaxbuf)
 {
 float newvariance;
-int max, min, x, i, j, prevquanta, availquanta;
-int levelcumbuf[DV_COUNT], levelminbuf[DV_COUNT], progressfactor = 0;
+int max, min, x, i, j, prevquanta, availquanta, localavailquanta;
+int levelcumbuf[DV_COUNT], levelminbuf[DV_COUNT], levelmaxbuf[DV_COUNT];
+int progressfactor = 0;
 
 for (i = 0; i <= GRfoodlevel[foodno]; i++) levelcumbuf[i] = oldlevelcumbuf[i];
 for (i = 0; i <= GRfoodlevel[foodno]; i++) levelminbuf[i] = oldlevelminbuf[i];
+for (i = 0; i <= GRfoodlevel[foodno]; i++) levelmaxbuf[i] = oldlevelmaxbuf[i];
+if (GRlowestlevelchange[foodno] < GRfoodlevel[foodno])
+ {
+ for (i = 0;  i <= GRlowestlevelchange[foodno]; i++) levelmaxbuf[i] = oldlevelcumbuf[i];
+ levelmaxbuf[0] = GRlowestlevelchange[foodno];
+ }
+if (foodno == 0)
+ {
+ for (i = 0;  i <= GRfoodlevel[foodno]; i++) levelmaxbuf[i] = oldlevelcumbuf[0];
+ levelmaxbuf[0] = 1;
+ }
 
 prevquanta = levelcumbuf[GRlowestlevelchange[foodno]];
 for (i = GRlowestlevelchange[foodno]; i <= GRfoodlevel[foodno]; i++) levelcumbuf[i] = 0;
 availquanta = levelminbuf[0] - levelcumbuf[0];
 
 max = availquanta < prevquanta ? availquanta : prevquanta;
+localavailquanta = levelmaxbuf[levelmaxbuf[0]] - levelcumbuf[levelmaxbuf[0]];
+if (GRlowestlevelchange[foodno] == GRfoodlevel[foodno] && max > localavailquanta) max = localavailquanta;
 
 if (GRlowestlevelchange[foodno] <= 1)
  {
@@ -737,7 +753,7 @@ for (x = max; x >= min; x--)
   }
  GRfoodslots[foodno] = x;
  for (i = foodno + 1; i < GRfoodcount; i++) GRfoodslots[i] = 0;
- if (availquanta - x > 0) solve_it(foodno + 1, levelcumbuf, levelminbuf);
+ if (availquanta - x > 0) solve_it(foodno + 1, levelcumbuf, levelminbuf, levelmaxbuf);
  else
   {
   for (j = 0; j < GRnutcount; j++)
@@ -786,7 +802,7 @@ for ( ; ; )
   read_weightlib(food_ptr->ndb_no,buf,sizeof(buf),result,resultparm);
   header("NUT:  Modify Serving Sizes");
   printf("%-60s   Grams  %8.2f\n",food_ptr->name,food_ptr->grams);
-  printf("Serving:  %-50s   Ounces: %7.2f\n\n",format_serving(servdisp,&one,food_ptr),food_ptr->grams / 28.35);
+  printf("Serving:  %-50s   Ounces: %7.2f\n\n",format_serving(servdisp,&one,food_ptr),food_ptr->grams / GRAMS_IN_OUNCE);
   for (i = 1; i <= resultcount / 3; i++)
    {
    strcpy(servdisp,result[3*i-3]);
@@ -824,7 +840,7 @@ for ( ; ; )
     get_recipe_qty(&food_work.grams);
     header("NUT:  Modify Serving Sizes");
     printf("%-60s   Grams  %8.2f\n",food_ptr->name,food_work.grams);
-    printf("Serving:  %-50s   Ounces  %7.2f\n\n"," ",food_work.grams / 28.35);
+    printf("Serving:  %-50s   Ounces  %7.2f\n\n"," ",food_work.grams / GRAMS_IN_OUNCE);
     spacer(3);
     printf("\nIs weight now correct?  (y/n):  ");
     junk = get_char();
@@ -840,7 +856,7 @@ for ( ; ; )
     }
    header("NUT:  Modify Serving Sizes");
    printf("%-60s   Grams  %8.2f\n",food_ptr->name,food_work.grams);
-   printf("Serving:  %-50s   Ounces  %7.2f\n\n","?",food_work.grams / 28.35);
+   printf("Serving:  %-50s   Ounces  %7.2f\n\n","?",food_work.grams / GRAMS_IN_OUNCE);
    spacer(3);
    junk = 'n';
    while (junk == 'n')
@@ -849,7 +865,7 @@ for ( ; ; )
     get_string(food_work.unit,50); 
     header("NUT:  Modify Serving Sizes");
     printf("%-60s   Grams  %8.2f\n",food_ptr->name,food_work.grams);
-    printf("Serving:  %-50s   Ounces  %7.2f\n\n","?",food_work.grams / 28.35);
+    printf("Serving:  %-50s   Ounces  %7.2f\n\n","?",food_work.grams / GRAMS_IN_OUNCE);
     spacer(3);
     printf("\nIs \"%-s\" correct?  (y/n)  ",food_work.unit);
     junk = get_char();
@@ -860,14 +876,14 @@ for ( ; ; )
     {
     header("NUT:  Modify Serving Sizes");
     printf("%-60s   Grams  %8.2f\n",food_ptr->name,food_work.grams);
-    printf("Serving:  %-50s   Ounces  %7.2f\n\n",format_serving(servdisp,&one,&food_work),food_work.grams / 28.35);
+    printf("Serving:  %-50s   Ounces  %7.2f\n\n",format_serving(servdisp,&one,&food_work),food_work.grams / GRAMS_IN_OUNCE);
     spacer(3);
     printf("\nPlease enter number of serving units:  ");
     food_work.qty = get_float(); 
     if (food_work.qty <= 0) food_work.qty = 1;
     header("NUT:  Modify Serving Sizes");
     printf("%-60s   Grams  %8.2f\n",food_ptr->name,food_work.grams);
-    printf("Serving:  %-50s   Ounces  %7.2f\n\n",format_serving(servdisp,&one,&food_work),food_work.grams / 28.35);
+    printf("Serving:  %-50s   Ounces  %7.2f\n\n",format_serving(servdisp,&one,&food_work),food_work.grams / GRAMS_IN_OUNCE);
     spacer(3);
     printf("\nIs \"%-1.2f\" the correct number of serving units?  (y/n)  ",food_work.qty);
     junk = get_char();
