@@ -2,7 +2,7 @@
 
 /*
     NUT nutrition software 
-    Copyright (C) 1996-2007 by Jim Jozwiak.
+    Copyright (C) 1996-2008 by Jim Jozwiak.
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -691,7 +691,6 @@ fprintf(fp,"%d^%d^\n",CUSTOM,options.custom);
 fprintf(fp,"%d^%f^\n",PCPROTEIN,options.pcprotein);
 fprintf(fp,"%d^%f^\n",PCCARB,options.pccarb);
 fprintf(fp,"%d^%f^\n",PCSATFAT,options.pcsatfat);
-fprintf(fp,"%d^%f^\n",FATPROTRATIO,options.fatprotratio);
 fprintf(fp,"%d^%d^\n",NEXT_RECIPE,options.next_recipe);
 fprintf(fp,"%d^%d^\n",MEALSPERDAY,options.mealsperday);
 fprintf(fp,"%d^%d^\n",GRAMS,options.grams);
@@ -701,7 +700,9 @@ fprintf(fp,"%d^%f^\n",CARBCALPERGM,options.carbcalpergm);
 fprintf(fp,"%d^%f^\n",FATCALPERGM,options.fatcalpergm);
 fprintf(fp,"%d^%f^\n",FATTYACIDFACTOR,options.fattyacidfactor);
 fprintf(fp,"%d^%f^\n",N6HUFA,options.n6hufa);
-fprintf(fp,"%d^%d^\n",N6HUFASPEC,options.n6hufaspec);
+fprintf(fp,"%d^%f^\n",EPADHAMAX,options.epadhamax);
+fprintf(fp,"%d^%d^\n",DEFANALANAL,options.defanalanal);
+fprintf(fp,"%d^%d^\n",DEFANALREC,options.defanalrec);
 for (i = 1; i <= DV_COUNT; i++)
  {
  switch (DVMap[i])
@@ -802,8 +803,6 @@ while (fgets(buffer,100,fp) != NULL)
                         break;
   case PCSATFAT       : options.pcsatfat = atof(valbuf1);
                         break;
-  case FATPROTRATIO   : options.fatprotratio = atof(valbuf1);
-                        break;
   case NEXT_RECIPE    : options.next_recipe = atoi(valbuf1);
                         break;
   case MEALSPERDAY    : options.mealsperday = atoi(valbuf1);
@@ -822,7 +821,11 @@ while (fgets(buffer,100,fp) != NULL)
                         break;
   case N6HUFA          : options.n6hufa = atof(valbuf1);
                         break;
-  case N6HUFASPEC      : options.n6hufaspec = atoi(valbuf1);
+  case EPADHAMAX       : options.epadhamax = atof(valbuf1);
+                        break;
+  case DEFANALANAL     : options.defanalanal = atoi(valbuf1);
+                        break;
+  case DEFANALREC      : options.defanalrec = atoi(valbuf1);
                         break;
   case OPT_CHO_NONFIB : options.abnuts[CHO_NONFIB] = atof(valbuf1);
                         options.locknuts[CHO_NONFIB] = atoi(valbuf2);
