@@ -2,7 +2,7 @@
 
 /*
     NUT nutrition software 
-    Copyright (C) 1996-2007 by Jim Jozwiak.
+    Copyright (C) 1996-2008 by Jim Jozwiak.
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -198,45 +198,43 @@ void personal_menu()
 {
 int menu_choice;
 char calflag[20];
-char pufaflag[20];
 char pcproteinflag[20];
 char pccarbflag[20];
 char pcsatfatflag[20];
 char abproteinflag[20];
 char abcarbflag[20];
 char abfiberflag[20];
-char fatprotflag[20];
 for ( ; ; )
  {
- sprintf(calflag,"%s %5.1f %s",(options.locknuts[ENERC_KCAL] ? "(LOCKED:" : options.autocal ? "(AUTO-SET:"  : "(SET:"),options.abnuts[ENERC_KCAL],"kc)");
- sprintf(pufaflag,"%s %4.1f %s",options.locknuts[FAPU] ? "(LOCKED:" : "(SET:",options.abnuts[FAPU],"g)");
- if (options.locknuts[FAPU] == 0 && options.n6hufaspec) sprintf(pufaflag,"%s","(SPECIAL)");
+ sprintf(calflag,"%s  %5.1f %s",(options.locknuts[ENERC_KCAL] ? "(LOCKED:" : options.autocal ? "(AUTO-SET:"  : "(SET:"),options.abnuts[ENERC_KCAL],"kc)");
  sprintf(pcproteinflag,"%s %5.1f%s",options.locknuts[PROCNT] && options.pcprotein > 0 ? "(LOCKED:" : "(SET:",options.pcprotein,"%)");
  sprintf(pccarbflag,"%s %5.1f%s",options.locknuts[CHOCDF] && options.pccarb > 0 ? "(LOCKED:" : "(SET:",options.pccarb,"%)");
  sprintf(pcsatfatflag,"%s %5.1f%s",options.locknuts[FASAT] ? "(LOCKED:" : "(SET:",options.pcsatfat,"%)");
- sprintf(abproteinflag,"%s %5.1f %s",options.locknuts[PROCNT] && options.abnuts[PROCNT] > 0 ? "(LOCKED:" : "(SET:",options.abnuts[PROCNT],"g)");
- sprintf(abcarbflag,"%s %5.1f %s",options.locknuts[CHOCDF] && options.abnuts[CHOCDF] > 0 ? "(LOCKED:" : "(SET:",options.abnuts[CHOCDF],"g)");
+ sprintf(abproteinflag,"%s  %5.1f %s",options.locknuts[PROCNT] && options.abnuts[PROCNT] > 0 ? "(LOCKED:" : "(SET:",options.abnuts[PROCNT],"g)");
+ sprintf(abcarbflag,"%s  %5.1f %s",options.locknuts[CHOCDF] && options.abnuts[CHOCDF] > 0 ? "(LOCKED:" : "(SET:",options.abnuts[CHOCDF],"g)");
  sprintf(abfiberflag,"%s %5.1f %s",options.locknuts[FIBTG] ? "(LOCKED:" : "(SET:",options.abnuts[FIBTG],"g)");
- sprintf(fatprotflag,"%s %5.2f%s",options.fatprotratio > 0 && options.locknuts[PROCNT] ? "(LOCKED:" : "(SET:",options.fatprotratio,")");
  header("NUT:  Personal Options");
+ printf("\n");
  printf("                1  --  Change Calorie Level %s\n\n",options.abnuts[ENERC_KCAL] != 2000 || options.locknuts[ENERC_KCAL] || options.autocal ? calflag : "(default)");
- printf("                2  --  Essential Fats Absolute Amount %s\n\n",(options.abnuts[FAPU] || options.n6hufaspec) ? pufaflag : "(default)");
+ if (options.n6hufa == 0 && options.abnuts[FAPU] == 0) printf("                2  --  Essential Fatty Acid Options (default)\n\n");
+ else if (options.locknuts[FAPU] == 1) printf("                2  --  Essential Fatty Acid Options (LOCKED:  %3.1f g)\n\n",options.abnuts[FAPU]);
+ else if (options.n6hufa > 0 && options.abnuts[FAPU] == 0) printf("                2  --  Essential Fatty Acid Options (SET:  %2.0f/%2.0f)\n\n",options.n6hufa,100-options.n6hufa);
+ else if (options.abnuts[FAPU] > 0) printf("                2  --  Essential Fatty Acid Options (SET:  %3.1f g)\n\n",options.abnuts[FAPU]);
  printf("                3  --  Saturated Fat Percentage %s\n\n",options.pcsatfat ? pcsatfatflag : "(default)");
  printf("                4  --  Fiber Absolute Amount %s\n\n",options.abnuts[FIBTG] ? abfiberflag : "(default)");
  printf("                5  --  Carbohydrate Percentage %s\n\n",options.pccarb ? pccarbflag : "(default)");
  printf("                6  --  Protein Percentage %s\n\n",options.pcprotein ? pcproteinflag : "(default)");
  printf("                7  --  Carbohydrate Absolute Amount %s\n\n",options.abnuts[CHOCDF] ? abcarbflag : "(default)");
  printf("                8  --  Protein Absolute Amount %s\n\n",options.abnuts[PROCNT] ? abproteinflag : "(default)");
- printf("                9  --  Fat to Protein Ratio %s\n\n",options.fatprotratio > 0 ? fatprotflag : "(default)");
  printf("                0  --  Restore All Defaults\n");
- spacer(19);
+ spacer(18);
  printf("\nEnter your choice (just <enter> to quit):  ");
  menu_choice = get_char();
  switch (menu_choice)
   {
   case '1' : personal_cal();
              break; 
-  case '2' : efa_method();
+  case '2' : efa_options();
              break; 
   case '3' : satfat_percent();
              break; 
@@ -250,8 +248,6 @@ for ( ; ; )
              break; 
   case '8' : protein_absolute();
              break; 
-  case '9' : fatprot_ratio();
-             break; 
   case '0' : restore_defaults(1);
              break; 
   default  : return;
