@@ -2,7 +2,7 @@
 
 /*
     NUT nutrition software 
-    Copyright (C) 1996-2007 by Jim Jozwiak.
+    Copyright (C) 1996-2008 by Jim Jozwiak.
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -277,20 +277,20 @@ while (displayed <= (FoodCount - 20) && (junk == 'm' || junk == 'M'))
   if (opt == 5) strncpy(thisname,food_ptr->name,52); thisname[52] = '\0';
   if (opt == 2 && options.screen == 0)
    {
-   theseounces = abacus[max] * DV[num] / ( food_ptr->nutrient[num] * 28.35);
-   if (options.grams) printf("%-54s        %7.1f g %5.0f%%\n",thisname,theseounces*28.35,abacus[max]);
+   theseounces = abacus[max] * DV[num] / ( food_ptr->nutrient[num] * GRAMS_IN_OUNCE);
+   if (options.grams) printf("%-54s        %7.1f g %5.0f%%\n",thisname,theseounces*GRAMS_IN_OUNCE,abacus[max]);
    if (!options.grams) printf("%-54s        %6.1f oz %5.0f%%\n",thisname,theseounces,abacus[max]);
    }
   if (opt == 2 && options.screen > 0 && options.screen < 4)
    {
-   theseounces = abacus[max] / (food_ptr->nutrient[num] * 28.35);
-   if (options.grams) printf("%-54s %7.1f g %9.1f %-3s\n",thisname,theseounces*28.35,abacus[max]/100,Unit[num]);
+   theseounces = abacus[max] / (food_ptr->nutrient[num] * GRAMS_IN_OUNCE);
+   if (options.grams) printf("%-54s %7.1f g %9.1f %-3s\n",thisname,theseounces*GRAMS_IN_OUNCE,abacus[max]/100,Unit[num]);
    if (!options.grams) printf("%-54s %6.1f oz %9.1f %-3s\n",thisname,theseounces,abacus[max]/100,Unit[num]);
    }
   if (opt == 2 && options.screen > 3)
    {
-   theseounces = abacus[max] / (food_ptr->nutrient[num] * 28.35);
-   if (options.grams) printf("%-54s %7.1f g %9.2f %-3s\n",thisname,theseounces*28.35,abacus[max]/100,Unit[num]);
+   theseounces = abacus[max] / (food_ptr->nutrient[num] * GRAMS_IN_OUNCE);
+   if (options.grams) printf("%-54s %7.1f g %9.2f %-3s\n",thisname,theseounces*GRAMS_IN_OUNCE,abacus[max]/100,Unit[num]);
    if (!options.grams) printf("%-54s %6.1f oz %9.2f %-3s\n",thisname,theseounces,abacus[max]/100,Unit[num]);
    }
   if (opt == 1 && options.screen == 0) printf("%-54s                  %5.0f%%\n",thisname,abacus[max]);
@@ -300,24 +300,24 @@ while (displayed <= (FoodCount - 20) && (junk == 'm' || junk == 'M'))
   if (opt == 6 && options.screen > 0 && options.screen < 4) printf("%-54s          %10.1f %-3s\n",thisname,abacus[max],Unit[num]);
   if (opt == 6 && options.screen > 0 && options.screen > 3) printf("%-54s          %10.2f %-3s\n",thisname,abacus[max],Unit[num]);
   if (opt == 3 && options.screen == 0 && options.grams) printf("%-54s        %7.1f g %5.0f%%\n",thisname,10000 / (100 - food_ptr->nutrient[WATER]),abacus[max]);
-  if (opt == 3 && options.screen == 0 && !options.grams) printf("%-54s        %6.1f oz %5.0f%%\n",thisname,10000 / (100 - food_ptr->nutrient[WATER]) / 28.35,abacus[max]);
+  if (opt == 3 && options.screen == 0 && !options.grams) printf("%-54s        %6.1f oz %5.0f%%\n",thisname,10000 / (100 - food_ptr->nutrient[WATER]) / GRAMS_IN_OUNCE,abacus[max]);
   if (opt == 3 && options.screen > 0 && options.screen < 4 && options.grams) printf("%-54s %7.1f g %9.1f %-3s\n",thisname,10000 / (100 - food_ptr->nutrient[WATER]),abacus[max],Unit[num]);
-  if (opt == 3 && options.screen > 0 && options.screen < 4 && !options.grams) printf("%-54s %6.1f oz %9.1f %-3s\n",thisname,10000 / (100 - food_ptr->nutrient[WATER]) / 28.35,abacus[max],Unit[num]);
+  if (opt == 3 && options.screen > 0 && options.screen < 4 && !options.grams) printf("%-54s %6.1f oz %9.1f %-3s\n",thisname,10000 / (100 - food_ptr->nutrient[WATER]) / GRAMS_IN_OUNCE,abacus[max],Unit[num]);
   if (opt == 3 && options.screen > 0 && options.screen > 3 && options.grams) printf("%-54s %7.1f g %9.2f %-3s\n",thisname,10000 / (100 - food_ptr->nutrient[WATER]),abacus[max],Unit[num]);
-  if (opt == 3 && options.screen > 0 && options.screen > 3 && !options.grams) printf("%-54s %6.1f oz %9.2f %-3s\n",thisname,10000 / (100 - food_ptr->nutrient[WATER]) / 28.35,abacus[max],Unit[num]);
+  if (opt == 3 && options.screen > 0 && options.screen > 3 && !options.grams) printf("%-54s %6.1f oz %9.2f %-3s\n",thisname,10000 / (100 - food_ptr->nutrient[WATER]) / GRAMS_IN_OUNCE,abacus[max],Unit[num]);
   if (opt == 0 && options.screen == 0 && options.grams) printf("%-54s        %7.1f g %5.0f%%\n",thisname,10000 / food_ptr->nutrient[ENERC_KCAL],abacus[max]);
-  if (opt == 0 && options.screen == 0 && !options.grams) printf("%-54s        %6.1f oz %5.0f%%\n",thisname,10000 / food_ptr->nutrient[ENERC_KCAL] / 28.35,abacus[max]);
+  if (opt == 0 && options.screen == 0 && !options.grams) printf("%-54s        %6.1f oz %5.0f%%\n",thisname,10000 / food_ptr->nutrient[ENERC_KCAL] / GRAMS_IN_OUNCE,abacus[max]);
   if (opt == 0 && options.screen > 0 && options.screen < 4 && options.grams) printf("%-54s %7.1f g %9.1f %-3s\n",thisname,10000 / food_ptr->nutrient[ENERC_KCAL],abacus[max],Unit[num]);
-  if (opt == 0 && options.screen > 0 && options.screen < 4 && !options.grams) printf("%-54s %6.1f oz %9.1f %-3s\n",thisname,10000 / food_ptr->nutrient[ENERC_KCAL] / 28.35,abacus[max],Unit[num]);
+  if (opt == 0 && options.screen > 0 && options.screen < 4 && !options.grams) printf("%-54s %6.1f oz %9.1f %-3s\n",thisname,10000 / food_ptr->nutrient[ENERC_KCAL] / GRAMS_IN_OUNCE,abacus[max],Unit[num]);
   if (opt == 0 && options.screen > 0 && options.screen > 3 && options.grams) printf("%-54s %7.1f g %9.2f %-3s\n",thisname,10000 / food_ptr->nutrient[ENERC_KCAL],abacus[max],Unit[num]);
-  if (opt == 0 && options.screen > 0 && options.screen > 3 && !options.grams) printf("%-54s %6.1f oz %9.2f %-3s\n",thisname,10000 / food_ptr->nutrient[ENERC_KCAL] / 28.35,abacus[max],Unit[num]);
+  if (opt == 0 && options.screen > 0 && options.screen > 3 && !options.grams) printf("%-54s %6.1f oz %9.2f %-3s\n",thisname,10000 / food_ptr->nutrient[ENERC_KCAL] / GRAMS_IN_OUNCE,abacus[max],Unit[num]);
   if (opt == 5) printf("%-52s %7.1f %-3s    %7.1f %-3s\n",thisname,food_ptr->grams / 100 * food_ptr->nutrient[num],Unit[num],food_ptr->grams / 100 * food_ptr->nutrient[Minut],Unit[Minut]);
   if (opt == 4 && options.screen == 0 && options.grams) printf("%-54s        %7.1f g %5.0f%%\n",thisname,food_ptr->grams,abacus[max]);
-  if (opt == 4 && options.screen == 0 && !options.grams) printf("%-54s        %6.1f oz %5.0f%%\n",thisname,food_ptr->grams / 28.35,abacus[max]);
+  if (opt == 4 && options.screen == 0 && !options.grams) printf("%-54s        %6.1f oz %5.0f%%\n",thisname,food_ptr->grams / GRAMS_IN_OUNCE,abacus[max]);
   if (opt == 4 && options.screen > 0 && options.screen < 4 && options.grams) printf("%-54s %7.1f g %9.1f %-3s\n",thisname,food_ptr->grams,abacus[max],Unit[num]);
-  if (opt == 4 && options.screen > 0 && options.screen < 4 && !options.grams) printf("%-54s %6.1f oz %9.1f %-3s\n",thisname,food_ptr->grams / 28.35,abacus[max],Unit[num]);
+  if (opt == 4 && options.screen > 0 && options.screen < 4 && !options.grams) printf("%-54s %6.1f oz %9.1f %-3s\n",thisname,food_ptr->grams / GRAMS_IN_OUNCE,abacus[max],Unit[num]);
   if (opt == 4 && options.screen > 0 && options.screen > 3 && options.grams) printf("%-54s %7.1f g %9.2f %-3s\n",thisname,food_ptr->grams,abacus[max],Unit[num]);
-  if (opt == 4 && options.screen > 0 && options.screen > 3 && !options.grams) printf("%-54s %6.1f oz %9.2f %-3s\n",thisname,food_ptr->grams / 28.35,abacus[max],Unit[num]);
+  if (opt == 4 && options.screen > 0 && options.screen > 3 && !options.grams) printf("%-54s %6.1f oz %9.2f %-3s\n",thisname,food_ptr->grams / GRAMS_IN_OUNCE,abacus[max],Unit[num]);
   abacus[max] = 0;
   max = max_array(abacus);
   }
