@@ -2,7 +2,7 @@
 
 /*
     NUT nutrition software 
-    Copyright (C) 1996-2007 by Jim Jozwiak.
+    Copyright (C) 1996-2008 by Jim Jozwiak.
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -82,7 +82,7 @@ for ( ; ; )
     }
    else
     {
-    printf("\nEnter food name, # to delete, \".\" to analyze:  ");
+    printf("\nEnter food name, # to del/chg, \".\" to analyze:  ");
     get_string(key,60);
     if (strcmp(key,"") == 0)
      {
