@@ -2,7 +2,7 @@
 
 /*
     NUT nutrition software 
-    Copyright (C) 1996-2007 by Jim Jozwiak.
+    Copyright (C) 1996-2008 by Jim Jozwiak.
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -111,7 +111,7 @@ if (strchr(buff,'g') != NULL)
  }
 else if (strchr(buff,'o') != NULL)
  {
- *result = ((float) (atof(buff) * 28.35 / *grams));
+ *result = ((float) (atof(buff) * GRAMS_IN_OUNCE / *grams));
  options.grams = 0;
  }
 else if (strchr(buff,'c') != NULL) *result = ((float) (atof(buff) * 100 / *grams / *calories));
@@ -140,7 +140,7 @@ if (strchr(qtystring,'g') != NULL)
 else if (strchr(qtystring,'o') != NULL) 
  {
  options.grams = 0;
- return atof(qtystring) * 28.35;
+ return atof(qtystring) * GRAMS_IN_OUNCE;
  }
 else if (strchr(qtystring,'c') != NULL) return atof(qtystring) * 100 / food_ptr->nutrient[ENERC_KCAL];
 else if (strchr(qtystring,'/') != NULL)
